Crate kcr_isindir_github_com

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the isindir.github.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

isindir.github.com/v1alpha1

  • SopsSecret

isindir.github.com/v1alpha2

  • SopsSecret

isindir.github.com/v1alpha3

  • SopsSecret

Modules

v1alpha1
v1alpha2
v1alpha3