pub struct SopsSecretSops {
pub age: Option<Vec<SopsSecretSopsAge>>,
pub azure_kv: Option<Vec<SopsSecretSopsAzureKv>>,
pub encrypted_regex: Option<String>,
pub encrypted_suffix: Option<String>,
pub gcp_kms: Option<Vec<SopsSecretSopsGcpKms>>,
pub hc_vault: Option<Vec<SopsSecretSopsHcVault>>,
pub kms: Option<Vec<SopsSecretSopsKms>>,
pub lastmodified: Option<String>,
pub mac: Option<String>,
pub pgp: Option<Vec<SopsSecretSopsPgp>>,
pub version: Option<String>,
}Expand description
SopsSecret metadata
Fields
age: Option<Vec<SopsSecretSopsAge>>Age configuration
azure_kv: Option<Vec<SopsSecretSopsAzureKv>>Azure KMS configuration
encrypted_regex: Option<String>Regex used to encrypt SopsSecret resource This opstion should be used with more care, as it can make resource unapplicable to the cluster.
encrypted_suffix: Option<String>Suffix used to encrypt SopsSecret resource
gcp_kms: Option<Vec<SopsSecretSopsGcpKms>>Gcp KMS configuration
hc_vault: Option<Vec<SopsSecretSopsHcVault>>Hashicorp Vault KMS configurarion
kms: Option<Vec<SopsSecretSopsKms>>Aws KMS configuration
lastmodified: Option<String>LastModified date when SopsSecret was last modified
mac: Option<String>Mac - sops setting
pgp: Option<Vec<SopsSecretSopsPgp>>PGP configuration
version: Option<String>Version of the sops tool used to encrypt SopsSecret